@@ -24,15 +24,18 @@ class UrlSeoAdmin(
     list_display = [
         'url',
         'title',
+        'match_type',
         'index',
         'follow',
         'is_default'
     ]
     list_editable = [
+        'match_type',
         'index',
         'follow'
     ]
     list_filter = [
+        'match_type',
         'index',
         'follow'
     ]
@@ -48,10 +51,11 @@ class UrlSeoAdmin(
         (None, {
             'fields': (
                 'url',
+                'match_type',
                 'is_default'
             )
         }),
-        (pgettext_lazy('Url seo admin', 'Meta'), {
+        (pgettext_lazy('ok:seo', 'Meta'), {
             'fields': base_seo_fields,
         }),
     )
