@@ -1,6 +1,6 @@
 from django.utils.functional import SimpleLazyObject
 
-from .services import get_url_seo
+from .services import get_url_seo_by_match_type
 
 __all__ = (
     'url_seo_middleware',
@@ -13,7 +13,9 @@ def url_seo_middleware(get_response):
     """
 
     def middleware(request):
-        request.seo = SimpleLazyObject(lambda: get_url_seo(request))
+        request.seo = SimpleLazyObject(
+            lambda: get_url_seo_by_match_type(request)
+        )
 
         response = get_response(request)
 
