@@ -4,9 +4,7 @@ from django.utils.translation import pgettext_lazy
 
 from .base import BaseSeoModel
 from ..mixins.models import SeoTagsMixin
-from .. import settings
-
-SEO_VIEWS_CHOICES = settings.SEO_VIEWS_CHOICES
+from ..settings import SEO_VIEWS_CHOICES
 
 __all__ = (
     'ViewSeo',
@@ -22,15 +20,15 @@ class ViewSeo(SeoTagsMixin, BaseSeoModel):
     """
 
     view = models.CharField(
-        pgettext_lazy("View seo model", "View"),
+        pgettext_lazy("ok:seo", "View"),
         max_length=100,
         choices=SEO_VIEWS_CHOICES,
         unique=True
     )
 
     class Meta:
-        verbose_name = pgettext_lazy("View seo model", "View seo")
-        verbose_name_plural = pgettext_lazy("View seo model", "View seo")
+        verbose_name = pgettext_lazy("ok:seo", "View seo")
+        verbose_name_plural = pgettext_lazy("ok:seo", "View seo")
 
     def __str__(self) -> str:
         return self.title
